@@ -3,10 +3,6 @@
 package    # hidden from PAUSE
   github;
 
-BEGIN {
-    $github::VERSION = '0.11';
-}
-
 # ABSTRACT: GitHub Command Tools
 
 use strict;
@@ -27,15 +23,25 @@ github - GitHub Command Tools
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Fayland Lam <fayland@gmail.com>
 
+=item *
+
+William Orr <will@worrbase.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Fayland Lam.
+This software is copyright (c) 2012 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
